FROM debian/eol:jessie
MAINTAINER Le Filament <https://le-filament.com>

ENV APT_DEPS='python-dev build-essential libxml2-dev libxslt1-dev libjpeg-dev libfreetype6-dev \
              liblcms2-dev libopenjpeg-dev libtiff5-dev tk-dev tcl-dev linux-headers-amd64 \
              libpq-dev libldap2-dev libsasl2-dev' \
    LANG=C.UTF-8 \
    LC_ALL=C.UTF-8 \
    PGDATABASE=odoo

RUN set -x; \
        sed -Ei 's@(^deb http://deb.debian.org/debian jessie-updates main$)@#\1@' /etc/apt/sources.list &&\
        sed -i s/security.debian.org/archive.debian.org/g /etc/apt/sources.list &&\
        apt-get update &&\
        apt-get install -y --no-install-recommends \
            apt-transport-https \
            ca-certificates \
            curl \
            fontconfig \
            git \
            libjpeg62-turbo \
            libtiff5 \
            libx11-6 \
            libxcb1 \
            libxext6 \
            libxml2 \
            libxrender1 \
            libxslt1.1 \
            node-less \
            openssh-client \
            python-gevent \
            python-ldap \
            python-qrcode \
            python-renderpm \
            python-support \
            python-vobject \
            python-watchdog \
            sudo \
            xfonts-75dpi \
            xfonts-base \
            && \
        echo 'deb http://apt-archive.postgresql.org/pub/repos/apt/ jessie-pgdg main' >> /etc/apt/sources.list.d/postgresql.list &&\
        curl -SLk https://www.postgresql.org/media/keys/ACCC4CF8.asc | apt-key add - &&\
        curl -o wkhtmltox.deb -SL https://github.com/wkhtmltopdf/wkhtmltopdf/releases/download/0.12.5/wkhtmltox_0.12.5-1.jessie_amd64.deb &&\
        echo '4d104ff338dc2d2083457b3b1e9baab8ddf14202 wkhtmltox.deb' | sha1sum -c - &&\
        apt-get update &&\
        dpkg --install wkhtmltox.deb &&\
        apt-get install -y --no-install-recommends postgresql-client &&\
        apt-get install -y --no-install-recommends ${APT_DEPS} &&\
        curl https://bootstrap.pypa.io/pip/2.7/get-pip.py | python /dev/stdin &&\
        pip install -I -r https://raw.githubusercontent.com/OCA/OCB/10.0/requirements.txt &&\
        pip install simplejson WTForms Werkzeug==0.14.1 &&\
        apt-get -y purge ${APT_DEPS} &&\
        apt-get -y autoremove &&\
        rm -rf /var/lib/apt/lists/* wkhtmltox.deb

ARG SAVE_COMMITS_DIR='/opt/odoo_commits/'
ENV SAVE_COMMITS_DIR=$SAVE_COMMITS_DIR

# Add Git Known Hosts
COPY ./ssh_known_git_hosts /root/.ssh/known_hosts

# Install Odoo and remove not French translations and .git directory to limit amount of data used by container
ARG SAVE_COMMITS_FILENAME='ocb'
RUN set -x; \
  repo='https://github.com/OCA/OCB' \
  branch='10.0' \
  && useradd --create-home --home-dir /opt/odoo --no-log-init odoo \
  && /bin/bash -c "mkdir -p /opt/odoo/{etc,odoo,additional_addons,private_addons,data,private}" \
  && mkdir /opt/odoo_commits \
  && git clone --single-branch --branch "${branch}" --depth 1 "${repo}" /tmp/repo \
    && commit="$(git -C /tmp/repo rev-parse HEAD)" \
    && mv /tmp/repo/* /opt/odoo/odoo/ \
    && echo "repo;ref;commit" > $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME \
    && echo "${repo};${branch};${commit}" >> $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME \
  && rm -r /tmp/repo \
  # Only keep French translations.
  && find /opt/odoo/odoo/addons/*/i18n/ /opt/odoo/odoo/odoo/addons/base/i18n/ -type f -not -name 'fr.po' -delete \
  && echo "info: OCB commit:" \
  && cat $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME

# Add script to download Odoo addons.
COPY --chown=root:root --chmod=755 ./get_addons /usr/local/bin

# Install Odoo OCA default dependencies
ARG SAVE_COMMITS_FILENAME='default_addons'
RUN set -x; \
  get_addons 'https://github.com/OCA/account-financial-reporting' '10.0' 'additional_addons' \
    account_tax_balance \
  && get_addons 'https://github.com/OCA/bank-statement-import' '10.0' 'additional_addons' \
    account_bank_statement_import_ofx \
    account_bank_statement_import_qif \
  && get_addons 'https://github.com/OCA/knowledge' '10.0' 'additional_addons' \
    knowledge \
    document_page \
  && get_addons 'https://github.com/OCA/partner-contact' '10.0' 'additional_addons' \
    partner_firstname \
    partner_disable_gravatar \
  && get_addons 'https://github.com/OCA/server-tools' '10.0' 'additional_addons' \
    date_range \
    auth_session_timeout \
    auth_brute_force \
    password_security \
  && get_addons 'https://github.com/OCA/social' '10.0' 'additional_addons' \
    mail_debrand \
    mail_restrict_follower_selection \
  && get_addons 'https://github.com/OCA/web' '10.0' 'additional_addons' \
    web_environment_ribbon \
    web_export_view \
    web_responsive \
    web_timeline \
  # Only keep French translations.
  && find /opt/odoo/additional_addons/*/i18n/ -type f -not -name 'fr.po' -delete \
  # Print modules and commits.
  && echo "info: default addon commits:" \
  && cat $SAVE_COMMITS_DIR/$SAVE_COMMITS_FILENAME

# Copy entrypoint script and Odoo configuration file
COPY ./entrypoint.sh /
COPY ./odoo.conf /opt/odoo/etc/odoo.conf
RUN chown -R odoo:odoo /opt/odoo

# Mount /opt/odoo/data to allow restoring filestore
VOLUME ["/opt/odoo/data/"]

# Expose Odoo services
EXPOSE 8069

# Set default user when running the container
USER odoo

# Start
ENTRYPOINT ["/entrypoint.sh"]
CMD ["odoo"]

# Metadata
ARG VCS_REF
ARG BUILD_DATE
ARG VERSION
LABEL org.label-schema.schema-version="$VERSION" \
      org.label-schema.vendor=LeFilament \
      org.label-schema.license=Apache-2.0 \
      org.label-schema.build-date="$BUILD_DATE" \
      org.label-schema.vcs-ref="$VCS_REF" \
      org.label-schema.vcs-url="https://sources.le-filament.com/lefilament/odoo_docker"
